pygeodesy.unitsBase.Int

Package pygeodesy :: Module unitsBase :: Class Int |
[frames] | no frames]

# Class Int

          object --+
                   |
                 int --+
                       |
      object --+       |
               |       |
    named._Named --+   |
                   |   |
          _NamedUnit --+
                       |
                      Int

Known Subclasses:
  - units.Bool
  - , epsg.Epsg
  - , units.Int_
  - , units.Zone
  - , deprecated.consterns._Deprecated_Int

Named `int`.

Instance Methods
__repr__(self) Return a representation of this named `int`. |
__str__(self) Return this `Int` as standard `str`. |
toRepr(self, std=False, **unused) Return a representation of this `Int`. |
toStr(self, **unused) Return this `Int` as standard `str`. |
Inherited from `int`: `__abs__`, `__add__`, `__and__`, `__cmp__`, `__coerce__`, `__div__`, `__divmod__`, `__float__`, `__floordiv__`, `__format__`, `__getattribute__`, `__getnewargs__`, `__hash__`, `__hex__`, `__index__`, `__int__`, `__invert__`, `__long__`, `__lshift__`, `__mod__`, `__mul__`, `__neg__`, `__nonzero__`, `__oct__`, `__or__`, `__pos__`, `__pow__`, `__radd__`, `__rand__`, `__rdiv__`, `__rdivmod__`, `__rfloordiv__`, `__rlshift__`, `__rmod__`, `__rmul__`, `__ror__`, `__rpow__`, `__rrshift__`, `__rshift__`, `__rsub__`, `__rtruediv__`, `__rxor__`, `__sub__`, `__truediv__`, `__trunc__`, `__xor__`, `bit_length`, `conjugate` Inherited from `named._Named`: `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__delattr__`, `__init__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Static Methods
a new object with type S, a subtype of T |
__new__(cls, arg=None, name='', **Error_name_arg) New, named `Int`. |

Properties
Inherited from `int`: `denominator`, `imag`, `numerator`, `real` Inherited from `_NamedUnit`: `std_repr`, `units` Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __new__ (cls, arg=None, name='', **Error_name_arg) Static Method |
New, named `Int`. Arguments: `arg` - The value (any `type` acceptable to `int`). `name` - Optional name (`str`). `Error_name_arg` - Optional `Error=UnitError` to raise and optional `name=arg` keyword argument, inlieu of separate `arg` and `name` ones. Returns: a new object with type S, a subtype of T A named `Int`. Raises: `Error` - Invalid `arg`. Overrides: object.__new__

### __repr__ (self) (Representation operator) |
Return a representation of this named `int`. Overrides: object.__repr__ See Also: Method `Int.toRepr` and property `Int.std_repr`. Note: Use `env` variable `PYGEODESY_INT_STD_REPR=std` prior to `import pygeodesy` to get the standard `repr` or set property `std_repr=False` to always get the named `toRepr` representation.

### __str__ (self) (Informal representation operator) |
Return this `Int` as standard `str`. Overrides: object.__str__

### toRepr (self, std=False, **unused) |
Return a representation of this `Int`. Arguments: `std` - If `True`, return the standard `repr`, otherwise the named representation (`bool`). Overrides: named._Named.toRepr See Also: Method Int.__repr__ for more documentation.

### toStr (self, **unused) |
Return this `Int` as standard `str`. Overrides: named._Named.toStr See Also: Method Int.__repr__ for more documentation.